'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.get = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _requestretry = require('requestretry');

var _requestretry2 = _interopRequireDefault(_requestretry);

var _logger = require('./logger');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var get = exports.get = async function get(owner, env, config) {
  return new Promise(async function (resolve, reject) {
    try {
      if (!config || (typeof config === 'undefined' ? 'undefined' : _typeof(config)) !== 'object') return reject('Config param is missing or not an object type');
      if (!config.CONFIG_URL) return reject('Missing config url attribute of config object');
      if (!config.HEADER_TOKEN) return reject('Missing header token attribute of config object');
      if (!owner) return reject('Missing owner parameter');
      if (!env) return reject('Missing environment parameter');

      var url = config.CONFIG_URL + '/api/' + owner + '/' + env + '/config';
      var authorize = 'Bearer ' + config.HEADER_TOKEN;
      var response = await (0, _requestretry2.default)({
        url: url,
        method: 'get',
        json: true,
        fullResponse: false,
        headers: {
          authorization: authorize,
          'Content-Type': 'application/json',
          Accept: 'application/json'
        }
      }).then(function (r) {
        return r.data;
      }).catch(function (e) {
        _logger.log.error('getOwnerConfig: ', e);
        return reject(e);
      });
      return resolve(response);
    } catch (e) {
      return reject(e);
    }
  });
};