'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.send = undefined;

var _nodemailer = require('nodemailer');

var _nodemailer2 = _interopRequireDefault(_nodemailer);

var _logger = require('./logger');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultTo = 'dennis.toribio@viseo.com';
var defaultFrom = 'mailer <robutils@mailer.com>';

var getTransporter = function getTransporter(mailCreds) {
  return new Promise(function (resolve) {
    try {
      var transporter = _nodemailer2.default.createTransport(mailCreds);
      resolve(transporter);
    } catch (e) {
      _logger.log.error('getTransporter', e);
    }
  });
};

var sendEmail = function sendEmail(mailOptions, smtpTransport) {
  return new Promise(function (resolve, reject) {
    return smtpTransport.sendMail(mailOptions, function (error, response) {
      if (error) {
        _logger.log.error('Could not send email err: ' + error);
        return reject(error);
      }
      _logger.log.info('Message sent: ' + JSON.stringify(response.accepted));
      return resolve(response);
    });
  });
};

var send = exports.send = async function send(requestBody) {
  var from = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultFrom;
  var to = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultTo;
  var mailCreds = arguments[3];
  var store = arguments[4];

  try {
    var transporter = await getTransporter(mailCreds);
    var mailOptions = {
      from: from,
      to: to,
      subject: requestBody.subject + ' (store name: ' + store + ')',
      html: requestBody.body
    };
    if (requestBody.filePath) {
      mailOptions.attachments = [{
        path: requestBody.filePath
      }];
    }
    await sendEmail(mailOptions, transporter);
    return true;
  } catch (e) {
    _logger.log.error('sendEmailNotification', e);
    return e;
  }
};