'use strict';

var _json2csv = require('json2csv');

var _json2csv2 = _interopRequireDefault(_json2csv);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _momentTimezone = require('moment-timezone');

var _momentTimezone2 = _interopRequireDefault(_momentTimezone);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var filterRefundData = function filterRefundData(refundItem, itemId) {
  var result = {};
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = refundItem[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var data = _step.value;
      // eslint-disable-line
      var refundId = _lodash2.default.find(data.refund_line_items, { line_item_id: itemId });
      if (!_lodash2.default.isEmpty(refundId)) {
        return data;
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return result;
}; /* eslint-disable max-len */


var mappingOrderData = function mappingOrderData(order, storeCode) {
  var mappingItems = [];

  var commonMapData = {
    Store_Code: storeCode,
    Transaction_Number: _lodash2.default.toString(order.id),
    Transaction_DateTime: (0, _momentTimezone2.default)(order.created_at).format('YYYY/MM/DD HH:mm:ss'),
    Transaction_Amount: _lodash2.default.toString(order.total_price),
    Transaction_Discount: _lodash2.default.toString(order.total_discounts)
  };

  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _iterator2 = order.line_items[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var item = _step2.value;
      // eslint-disable-line
      var itemData = {};
      itemData = _lodash2.default.clone(commonMapData);

      var refundDetail = filterRefundData(order.refunds, item.id);

      itemData.Return_Transaction_Reference_Number = _lodash2.default.toString(refundDetail.id) || null;
      itemData.Return_Transaction_Purchase_DateTime = refundDetail.created_at || null;

      itemData.Customer_Id = order.customer ? order.customer.id : null;
      itemData.Customer_Mobile = order.customer && order.customer.phone ? order.customer.phone : order.shipping_address ? order.shipping_address.phone : null; // eslint-disable-line
      itemData.Customer_Email = order.email;

      itemData.Item_Code = _lodash2.default.toString(item.sku) || null;
      itemData.Item_Description = _lodash2.default.trim(item.title) || null;
      itemData.Item_Qty = _lodash2.default.toString(item.quantity);
      itemData.Item_Rate = _lodash2.default.toString(item.price);
      itemData.Item_Value = _lodash2.default.toString(item.quantity * item.price);
      itemData.Item_Discount = _lodash2.default.toString(item.total_discount);
      itemData.Item_Amount = _lodash2.default.toString(item.quantity * item.price - item.total_discount);

      mappingItems.push(itemData);
    }
  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2.return) {
        _iterator2.return();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return mappingItems;
};

var isNewsLetterSubscribed = function isNewsLetterSubscribed(tags) {
  if (!tags || typeof tags === 'string' && tags.indexOf('newsletter') === -1) {
    return 'N';
  }
  return 'Y';
};

var getGender = function getGender(note) {
  try {
    var noteByField = note.split('\n');
    var gender = noteByField.filter(function (val) {
      return val.indexOf('gender') >= 0;
    });
    return gender.length > 0 ? gender[0].split(':')[1].trim().charAt(0) : '';
  } catch (err) {
    return null;
  }
};

var shopifyToMemberson = function shopifyToMemberson(customers) {
  if (!Array.isArray(customers)) {
    return false;
  }

  return customers.map(function (customer) {
    var mappedCustomer = {
      'First Name': customer.first_name ? customer.first_name.substr(0, 50) : null,
      'Last Name': customer.last_name ? customer.last_name.substr(0, 50) : null,
      Email: customer.email,
      Gender: getGender(customer.note),
      'Member Since': customer.created_at
    };
    mappedCustomer['Accepts Marketing'] = customer.accepts_marketing ? 'Y' : 'N';
    mappedCustomer.Newsletter = isNewsLetterSubscribed(customer.tags);

    var defaultAddress = customer.addresses.filter(function (address) {
      return address.default;
    });
    if (defaultAddress.length > 0) {
      mappedCustomer['Address 1'] = defaultAddress[0].address1 ? defaultAddress[0].address1.substr(0, 100) : null;
      mappedCustomer['Address 2'] = defaultAddress[0].address2 ? defaultAddress[0].address2.substr(0, 100) : null;
      mappedCustomer['Address 3'] = null;
      mappedCustomer['Address 4'] = null;
      mappedCustomer.City = defaultAddress[0].city ? defaultAddress[0].city.substr(0, 50) : null;
      mappedCustomer.State = defaultAddress[0].province ? defaultAddress[0].province.substr(0, 50) : null;
      mappedCustomer['Country Code'] = defaultAddress[0].country_code;
      mappedCustomer['Postal Code'] = defaultAddress[0].zip ? defaultAddress[0].zip.substr(0, 10) : null;
      mappedCustomer.Mobile = defaultAddress[0].phone ? defaultAddress[0].phone.replace(/\D/g, '') : null;
    }
    return mappedCustomer;
  });
};
var getCustomerFields = function getCustomerFields() {
  return ['First Name', 'Last Name', 'Gender', 'Email', 'Mobile', 'Address 1', 'Address 2', 'Address 3', 'Address 4', 'City', 'State', 'Country Code', 'Postal Code', 'Accepts Marketing', 'Newsletter', 'Member Since'];
};

var jsonToCsvParser = function jsonToCsvParser(jsonObject, fields) {
  var withTitle = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  return (0, _json2csv2.default)({ data: jsonObject, fields: fields, hasCSVColumnTitle: withTitle });
};

var removeHtmlTags = function removeHtmlTags(html) {
  return html.replace(/<(?:.|\n)*?>/gm, '');
};

module.exports = {
  customer: {
    shopifyToMemberson: shopifyToMemberson,
    getCustomerFields: getCustomerFields,
    getGender: getGender
  },
  jsonToCsvParser: jsonToCsvParser,
  mappingOrderData: mappingOrderData,
  removeHtmlTags: removeHtmlTags
};